$ErrorActionPreference = 'Stop'; # stop on all errors
$packageName = 'bazel'
$url = "https://github.com/bazelbuild/bazel/releases/download/0.3.2/bazel-0.3.2-windows-x86_64.zip"
$checksum = "693e063812708775b5a9a8f3af14776e7cb98c8b3f12b416884de99fac3caedf"
$checksumType = 'sha256'
$url64bit = $url
$checksum64 = "693e063812708775b5a9a8f3af14776e7cb98c8b3f12b416884de99fac3caedf"
$checksumType64 = $checksumType
$toolsDir = Split-Path -parent $MyInvocation.MyCommand.Definition
$packageDir = Split-Path -parent $toolsDir
$binRoot = (Get-ToolsLocation) -replace "\\", "/"

Install-ChocolateyZipPackage -PackageName "$packageName" `
  -Url "$url" `
  -Checksum "$checksum" `
  -ChecksumType "$checksumType" `
  -Url64bit "$url64bit" `
  -Checksum64 "$checksum64" `
  -Checksum64Type "$checksumType64" `
  -UnzipLocation "$packageDir"

write-host "Ensure that msys2 dll is present in PATH to allow bazel to be run from non-msys2 shells"

# stolen from docs: https://github.com/chocolatey/choco/wiki/How-To-Parse-PackageParameters-Argument
$msys2Path = "c:\tools\msys64"
if ($packageParameters)
{
  $match_pattern = "\/(?<option>([a-zA-Z]+)):(?<value>([`"'])?([a-zA-Z0-9- _\\:\.]+)([`"'])?)|\/(?<option>([a-zA-Z]+))"
  $option_name = 'option'
  $value_name = 'value'

  if ($packageParameters -match $match_pattern)
  {
    $results = $packageParameters | Select-String $match_pattern -AllMatches
    $results.matches | % {
      $arguments.Add(
        $_.Groups[$option_name].Value.Trim(),
        $_.Groups[$value_name].Value.Trim())
    }
  }
  else
  {
    Throw "Package Parameters were found but were invalid (REGEX Failure)"
  }

  if ($arguments.ContainsKey("msys2Path")) {
    $msys2Path = $arguments["msys2Path"]
    Write-Host "msys2Path Argument Found: $msys2Path"
  }
}
Install-ChocolateyPath -PathToInstall "$msys2Path\usr\bin" -PathType "Machine"

$addToMsysPath = ($packageDir -replace 'c:\\','/c/') -replace '\\','/'
write-host @"
bazel installed to $packageDir

To use it in powershell or cmd, you should ensure your PATH environment variable contains
  $($msys2Path)\usr\bin
BEFORE both
  c:\windows\system32 (because bash-on-windows' bash.exe will be found here, if it's installed)
  any references to msysgit (like c:\program files (x86)\git\bin or c:\program files (x86)\git\cmd) (because git's vendored version of msys2 will interfere with the real msys2)

To use it in msys2, you should add that to your msys2 PATH:
  export PATH=$($addToMsysPath):`$PATH

You also need, in your msys2 environment:
  export JAVA_HOME="`$(ls -d C:/Program\ Files/Java/jdk* | sort | tail -n 1)`"
  export BAZEL_SH=c:/tools/msys64/usr/bin/bash.exe
  export BAZEL_PYTHON=c:/tools/python2/python.exe

See also https://bazel.io/docs/windows.html
"@

